@@ -1,7 +1,9 @@
-package Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs 2.62 {
+package Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs 2.63 {
 
-  use 5.014;
+  use 5.020;
   use Moose;
+  use experimental qw( postderef );
+  use Dist::Zilla::Plugin::Author::Plicease;
 
   # ABSTRACT: Special prereq handling
 
@@ -22,6 +24,16 @@ package Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs 2.62 {
     default => sub { [] },
   );
 
+  has win32 => (
+    is      => 'ro',
+    default => 0,
+  );
+
+  has git => (
+    is      => 'ro',
+    default => 0,
+  );
+
   sub register_prereqs
   {
     my($self) = @_;
@@ -120,7 +132,7 @@ package Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs 2.62 {
         Test2::Util::Table::LineBreak
     );
 
-    foreach my $upgrade (@{ $self->upgrade })
+    foreach my $upgrade ($self->upgrade->@*)
     {
       if($upgrade =~ /^\s*(\S+)\s*=\s*(\S+)\s*$/)
       {
@@ -134,9 +146,9 @@ package Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs 2.62 {
 
     foreach my $phase (keys %$prereqs)
     {
-      foreach my $type (keys %{ $prereqs->{$phase} })
+      foreach my $type (keys $prereqs->{$phase}->%*)
       {
-        foreach my $module (sort keys %{ $prereqs->{$phase}->{$type} })
+        foreach my $module (sort keys $prereqs->{$phase}->{$type}->%*)
         {
           my $value = $prereqs->{$phase}->{$type}->{$module};
           next unless $value == 0;
@@ -153,9 +165,9 @@ package Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs 2.62 {
 
     foreach my $phase (keys %$prereqs)
     {
-      foreach my $type (keys %{ $prereqs->{$phase} })
+      foreach my $type (keys $prereqs->{$phase}->%*)
       {
-        foreach my $module (keys %{ $prereqs->{$phase}->{$type} })
+        foreach my $module (keys $prereqs->{$phase}->{$type}->%*)
         {
           if($module =~ /^(JSON|PerlX::Maybe)$/)
           {
@@ -188,8 +200,28 @@ package Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs 2.62 {
   sub before_release
   {
     my $self = shift;
-    $self->log_fatal('don\'t release via MSWin32')           if $^O eq 'MSWin32';
-    $self->log_fatal('don\'t release without Git plugins')   if $ENV{PLICEASE_DZIL_NO_GIT};
+
+    if($self->win32)
+    {
+      if($^O ne 'MSWin32')
+      {
+        $self->log_fatal("This dist must be released on MSWin32");
+      }
+    }
+    else
+    {
+      if($^O eq 'MSWin32')
+      {
+        $self->log_fatal("This dist is not releasable on MSWin32");
+      }
+    }
+
+    unless(Dist::Zilla::Plugin::Author::Plicease->git)
+    {
+      $self->log_fatal("release requires git and Dist::Zilla::Plugin::Git to be installed");
+    }
+
+    $self->log("Okay to release this dist on $^O");
   }
 
   sub setup_installer
@@ -202,13 +234,13 @@ package Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs 2.62 {
 
     $self->log("perl version required = $perl_version");
 
-    foreach my $file (grep { $_->name =~ /^(Makefile\.PL|Build\.PL)$/ } @{ $self->zilla->files })
+    foreach my $file (grep { $_->name =~ /^(Makefile\.PL|Build\.PL)$/ } $self->zilla->files->@*)
     {
       my $content = $file->content;
       $content = join "\n",
         "BEGIN {",
         "  use strict; use warnings;",
-        (map { s/^\| /  /r } @{ $self->preamble }),
+        (map { s/^\| /  /r } $self->preamble->@*),
         "  unless(eval q{ use $perl_version; 1}) {",
         "    print \"Perl $perl_version or better required\\n\";",
         "    exit;",
@@ -236,7 +268,7 @@ Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs - Special prereq handling
 
 =head1 VERSION
 
-version 2.62
+version 2.63
 
 =head1 SYNOPSIS
 
@@ -253,8 +285,9 @@ Some modules are recommended if certain modules are already
 prerequisites.  For example, XS modules may be recommended if
 otherwise pure perl modules will optionally use them.
 
-This plugin also enforces that releases are not done on
-Perl 5.8 or C<MSWin32>.
+This plugin also enforces that releases are done on MSWin32
+for pure-C<Win32::> type modules and on a Unixy platform
+if they are not.
 
 This plugin also adds a preface to your C<Makefile.PL> or C<Build.PL> to
 test the Perl version in a way that will not throw an exception,
@@ -308,6 +341,27 @@ Require 0.11 for dealing with C<exit> inside and C<eval>.
 
 =back
 
+=head1 OPTIONS
+
+=head2 preamble
+
+...
+
+=head2 upgrade
+
+Upgrade additional prereqs.  This takes a key=value pair, so something like
+
+ [Author::Plicease::SpecialPrereqs]
+ upgrade = Foo::Bar = 0.02
+
+=head2 win32
+
+If set to true, then the dist MUST be released on MSWin32.  This is
+useful for C<Win32::> type dists that aren't testable on Unixy platforms.
+
+If set to false, then the dist MUST NOT be released on MSWin32.  This
+is a personal preference; I prefer not to release on non-Unixy platforms.
+
 =head1 SEE ALSO
 
 =over 4
