@@ -1,6 +1,6 @@
-package Dist::Zilla::PluginBundle::Author::Plicease 2.62 {
+package Dist::Zilla::PluginBundle::Author::Plicease 2.63 {
 
-  use 5.024;
+  use 5.020;
   use Moose;
   use Dist::Zilla;
   use PerlX::Maybe qw( maybe );
@@ -10,6 +10,7 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.62 {
   use Path::Tiny qw( path );
   use File::Glob qw( bsd_glob );
   use Path::Tiny qw( path );
+  use Dist::Zilla::Plugin::Author::Plicease;
 
   # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
 
@@ -40,6 +41,20 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.62 {
   {
     my($self) = @_;
 
+    foreach my $key (qw( travis_status travis_com travis_base travis_image_base appveyor travis_user appveyor_user ))
+    {
+      my $bad = 0;
+      if(defined $self->payload->{$key})
+      {
+        print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
+        print STDERR "dist.ini [\@Author::Plicease] key $key is no longer supported";
+        print STDERR Term::ANSIColor::color('reset') if -t STDERR;
+        print STDERR "\n";
+        $bad = 1;
+      }
+      die "unsuppor" if $bad;
+    }
+
     if($INC{"Archive/Tar/Wrapper.pm"})
     {
       # https://github.com/PerlAlien/Alien-Build/issues/228
@@ -95,7 +110,7 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.62 {
     $self->_my_add_plugin(
       ['GatherDir' => { exclude_filename => [qw( Makefile.PL Build.PL xt/release/changes.t xt/release/fixme.t )],
                         exclude_match => '^_build/' }, ],
-      [ PruneCruft => { except => '.travis.yml' } ],
+      [ 'PruneCruft'   ],
       [ 'ManifestSkip' ],
       [ 'MetaYAML',    ],
       [ 'License',     ],
@@ -154,7 +169,7 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.62 {
     )]);
     $self->_my_add_plugin(['MetaJSON']);
 
-    if($^O ne 'MSWin32' && !$ENV{PLICEASE_DZIL_NO_GIT})
+    if(Dist::Zilla::Plugin::Author::Plicease->git)
     {
       foreach my $plugin (qw( Git::Check Git::Commit Git::Tag Git::Push ))
       {
@@ -197,7 +212,6 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.62 {
     $self->_my_add_plugin(map { [$_] } qw(
 
       InstallGuide
-      ConfirmRelease
 
     ));
 
@@ -207,6 +221,20 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.62 {
       },
     ]);
 
+    $self->_my_add_plugin([
+      'Author::Plicease::SpecialPrereqs' => {
+        maybe upgrade  => $self->payload->{upgrade},
+        maybe preamble => $self->payload->{preamble},
+        maybe win32    => $self->payload->{win32},
+      },
+    ]);
+
+    $self->_my_add_plugin(map { [$_] } qw(
+
+      ConfirmRelease
+
+    ));
+
     unless($self->payload->{no_readme})
     {
       $self->_my_add_plugin([
@@ -228,13 +256,6 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.62 {
           maybe default_branch    => $self->payload->{default_branch},
 
           # these are for my ReadmeAnyFromPod wrapper.
-                travis_status     => int(defined $self->payload->{travis_status} ? $self->payload->{travis_status} : 0),
-          maybe appveyor          => $self->payload->{appveyor},
-          maybe travis_user       => $self->payload->{travis_user} // $self->payload->{github_user},
-          maybe travis_com        => $self->payload->{travis_com},
-          maybe travis_base       => $self->payload->{travis_base},
-          maybe travis_image_base => $self->payload->{travis_image_base},
-          maybe appveyor_user     => $self->payload->{appveyor_user},
           maybe cirrus_user       => $self->payload->{cirrus_user},
           maybe github_user       => $self->payload->{github_user},
           maybe workflow          => $self->payload->{workflow},
@@ -242,13 +263,6 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.62 {
      ]);
     }
 
-    $self->_my_add_plugin([
-      'Author::Plicease::SpecialPrereqs' => {
-        maybe upgrade  => $self->payload->{upgrade},
-        maybe preamble => $self->payload->{preamble},
-      },
-    ]);
-
     if($self->payload->{copy_mb})
     {
       $self->_my_add_plugin([
@@ -310,7 +324,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 2.62
+version 2.63
 
 =head1 SYNOPSIS
 
@@ -372,8 +386,6 @@ This plugin bundle is mostly equivalent to
  exclude_match = ^_build/
  
  [PruneCruft]
- except = .travis.yml
- 
  [ManifestSkip]
  [MetaYAML]
  [License]
@@ -416,8 +428,9 @@ This plugin bundle is mostly equivalent to
  repository.web = https://github.com/plicease/My-Dist
  
  [InstallGuide]
- [ConfirmRelease]
  [MinimumPerl]
+ [Author::Plicease::SpecialPrereqs]
+ [ConfirmRelease]
  
  [Author::Plicease::ReadmeAnyFromPod]
  filename = README
@@ -427,24 +440,10 @@ This plugin bundle is mostly equivalent to
  [Author::Plicease::ReadmeAnyFromPod / ReadMePodInRoot]
  filename = README.md
  location = root
- travis_status = 0
  type = gfm
  
- [Author::Plicease::SpecialPrereqs]
  [Author::Plicease::NoUnsafeInc]
 
-Some exceptions:
-
-=over 4
-
-=item MSWin32
-
-Installing L<Dist::Zilla::Plugin::Git::*> on MSWin32 is a pain
-so it is also not a prereq on that platform, isn't used and as a result
-releasing from MSWin32 is not allowed.
-
-=back
-
 =head1 OPTIONS
 
 =head2 installer
@@ -475,26 +474,6 @@ If set to true, then include release tests when building.
 Passed into the L<Author::Plicease::Tests|Dist::Zilla::Plugin::Author::Plicease::Tests>
 if C<release_tests> is true.
 
-=head2 travis_status
-
-if set to true, then include a link to the travis build page in the readme.
-
-=head2 travis_com
-
-If set to true use travis-ci.com instead of travis-ci.org.
-
-=head2 travis_base
-
-Base URL for travis-ci.
-
-=head2 travis_image_base
-
-Base URL for the travis-ci status button.
-
-=head2 appveyor
-
-if set to a appveyor id, then include a link to the appveyor build page in the readme.
-
 =head2 mb_class
 
 if builder = ModuleBuild, this is the mb_class passed into the [ModuleBuild]
@@ -508,17 +487,9 @@ Set the GitHub repo name to something other than the dist name.
 
 Set the GitHub user name.
 
-=head2 travis_user
-
-Set the travis user name (defaults to github_user).
-
-=head2 appveyor_user
-
-Set the appveyor username (defaults to plicease).
-
 =head2 cirrus_user
 
-Set the cirrus-ci user (defaults to same as travis_user, which itself defaults to plicease).
+Set the cirrus-ci user (defaults to same as github_user, which itself defaults to plicease).
 
 =head2 copy_mb
 
@@ -549,6 +520,14 @@ Specify an alternative to OurPkgVersion for updating the versions in .pm files.
 
 Specify a minimum Perl version.  If not specified it will be detected.
 
+=head2 win32
+
+If set to true, then the dist MUST be released on MSWin32.  This is
+useful for C<Win32::> type dists that aren't testable on Unixy platforms.
+
+If set to false, then the dist MUST NOT be released on MSWin32.  This
+is a personal preference; I prefer not to release on non-Unixy platforms.
+
 =head1 SEE ALSO
 
 =over 4
